@@ -89,9 +89,9 @@ class Error(BaseError):
 
     def __eq__(self, obj: Any, /) -> bool:
         return isinstance(obj, self.__class__) \
-            and type(self._code) == type(obj._code) and self._code == obj._code \
-            and type(self._message) == type(obj._message) and self._message == obj._message \
-            and type(self._data) == type(obj._data) and self._data == obj._data
+            and type(self._code) is type(obj._code) and self._code == obj._code \
+            and type(self._message) is type(obj._message) and self._message == obj._message \
+            and type(self._data) is type(obj._data) and self._data == obj._data
 
     @property
     def code(self) -> int:
